    	HA.configs.HTTPS_to_HTTP

''' priorities: import vessels.proxies.HA as HA_Proxy HA_PROXY.start () ''' ''' priorities: [ ] SSL [ ] routing 80 -> 443 443 -> 8000 -> 8001 ''' ''' # # config check: # os.system (f"haproxy -f '{ config_path }' -c") os.system ("systemctl restart haproxy") os.system (f"cat '{ config_path }'") os.system ("systemctl status haproxy -l --no-pager") ''' ''' HAProxy installation: # https://packages.fedoraproject.org/pkgs/haproxy/haproxy/ dnf install haproxy start: python3 -m http.server 8000 python3 -m http.server 8001 haproxy -f haproxy.conf -c maybe? selinux: getsebool(8), booleans(8), togglesebool(8), semanage(8) # # https://stackoverflow.com/questions/35917129/selinux-denying-haproxy-connections # setsebool -P haproxy_connect_any 1 # # put linux in permissive mode # setenforce 0 systemctl: # /usr/sbin/haproxy -Ws -f /etc/haproxy/haproxy.cfg -f /etc/haproxy/conf.d -p /run/haproxy.pid systemctl start haproxy tutorial: https://docs.haproxy.org/dev/configuration.html#2.7 https://github.com/socketio/socket.io/blob/master/examples/cluster-haproxy/haproxy/haproxy.cfg logging: journalctl -u haproxy.service --no-pager '''